[Qa-jenkins-scm] [Git][qa/jenkins.debian.net][master] reproducible Debian: handle false positive diskspace issue when building clisp

Holger Levsen gitlab at salsa.debian.org
Sat Jun 9 13:47:07 BST 2018


Holger Levsen pushed to branch master at Debian QA / jenkins.debian.net


Commits:
e23f278d by Holger Levsen at 2018-06-09T12:46:54+00:00
reproducible Debian: handle false positive diskspace issue when building clisp

Signed-off-by: Holger Levsen <holger at layer-acht.org>

- - - - -


1 changed file:

- bin/reproducible_build.sh


Changes:

=====================================
bin/reproducible_build.sh
=====================================
--- a/bin/reproducible_build.sh
+++ b/bin/reproducible_build.sh
@@ -1,7 +1,7 @@
 #!/bin/bash
 # vim: set noexpandtab:
 
-# Copyright 2014-2017 Holger Levsen <holger at layer-acht.org>
+# Copyright 2014-2018 Holger Levsen <holger at layer-acht.org>
 #         © 2015-2018 Mattia Rizzolo <mattia at debian.org>
 # released under the GPLv=2
 
@@ -271,8 +271,8 @@ handle_ftbfs() {
 			fi
 		done
 		# notify about unkown diskspace issues where we are not 100% sure yet those are diskspace issues
-		# ignore syslinux, which is a false positive…
-		if zgrep -e "No space left on device" "$DEBIAN_BASE/logs/$SUITE/$ARCH/${SRCPACKAGE}_${EVERSION}.build${BUILD}.log.gz" && [ "$SRCPACKAGE" != "syslinux" ] ; then
+		# ignore syslinux and clisp, which are false positives…
+		if zgrep -e "No space left on device" "$DEBIAN_BASE/logs/$SUITE/$ARCH/${SRCPACKAGE}_${EVERSION}.build${BUILD}.log.gz" && [ "$SRCPACKAGE" != "syslinux" ] && [ "$SRCPACKAGE" != "clisp" ] ; then
 			MESSAGE="${BUILD_URL}console.log for ${SRCPACKAGE} (ftbfs in $SUITE/$ARCH) _probably_ had a diskspace issue on $node. Please check, tune handle_ftbfs() and reschedule the package."
 			echo $MESSAGE | tee -a /var/log/jenkins/reproducible-diskspace-issues.log
 			irc_message debian-reproducible "$MESSAGE"



View it on GitLab: https://salsa.debian.org/qa/jenkins.debian.net/commit/e23f278dffd3f06089f53b901ada782bcdffb587

-- 
View it on GitLab: https://salsa.debian.org/qa/jenkins.debian.net/commit/e23f278dffd3f06089f53b901ada782bcdffb587
You're receiving this email because of your account on salsa.debian.org.
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://alioth-lists.debian.net/pipermail/qa-jenkins-scm/attachments/20180609/ecf061fa/attachment-0001.html>


More information about the Qa-jenkins-scm mailing list